@@ -38,7 +38,8 @@ class RDocGeneratorMarkupTest < RDoc::TestCase
   def test_description
     @comment = '= Hello'
 
-    assert_equal "\n<h1 id=\"label-Hello\"><a href=\"#label-Hello\">Hello</a></h1>\n", description
+    # When there's no context (self returns nil for aref), there's no context prefix in the legacy label
+    assert_equal "\n<span id=\"label-Hello\" class=\"legacy-anchor\"></span>\n<h1 id=\"hello\"><a href=\"#hello\">Hello</a></h1>\n", description
   end
 
   def test_formatter
