@@ -1089,7 +1089,7 @@ and an extra note.[^2]
     doc = parse "it ~~works~~\n"
 
     expected = @RM::Document.new(
-      @RM::Paragraph.new("it ~works~"))
+      @RM::Paragraph.new("it <del>works</del>"))
 
     assert_equal expected, doc
   end
@@ -1098,7 +1098,7 @@ and an extra note.[^2]
     doc = parse "it ~~works fine~~\n"
 
     expected = @RM::Document.new(
-      @RM::Paragraph.new("it <s>works fine</s>"))
+      @RM::Paragraph.new("it <del>works fine</del>"))
 
     assert_equal expected, doc
   end
@@ -1114,6 +1114,34 @@ and an extra note.[^2]
     assert_equal expected, doc
   end
 
+  def test_strike_to_html_single_word
+    doc = parse "This is ~~strikethrough~~ text.\n"
+    html = @to_html.convert doc
+
+    assert_match %r{<del>strikethrough</del>}, html
+  end
+
+  def test_strike_to_html_multiple_words
+    doc = parse "This is ~~multiple words~~ text.\n"
+    html = @to_html.convert doc
+
+    assert_match %r{<del>multiple words</del>}, html
+  end
+
+  def test_strike_to_html_with_s_tag
+    doc = parse "This has <s>deleted</s> text.\n"
+    html = @to_html.convert doc
+
+    assert_match %r{<del>deleted</del>}, html
+  end
+
+  def test_strike_to_html_with_del_tag
+    doc = parse "This has <del>deleted</del> text.\n"
+    html = @to_html.convert doc
+
+    assert_match %r{<del>deleted</del>}, html
+  end
+
   def test_parse_style
     @parser.css = true
 
@@ -1283,6 +1311,16 @@ and an extra note.[^2]
     assert_includes html, '<a href="https://example.com">Link to <code>Foo</code> and <code>Bar</code> and <code>Baz</code></a>'
   end
 
+  def test_code_span_preserves_inline_formatting_chars
+    # Code spans should display formatting characters literally, not as styling
+    doc = parse "Code: `*bold*` and `_em_` and `+tt+`"
+    html = @to_html.convert doc
+
+    assert_includes html, '<code>*bold*</code>'
+    assert_includes html, '<code>_em_</code>'
+    assert_includes html, '<code>+tt+</code>'
+  end
+
   def parse(text)
     @parser.parse text
   end
